@@ -100,7 +100,7 @@ def test_something():
 | -    assert 2 == snapshot(1+1)                                               |
 | +    assert 2 == snapshot(2)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=update
+These changes will be applied, because you used update
 """
     )
 
@@ -127,7 +127,7 @@ def test_a():
         """\
 >       assert outsource("test2") == snapshot(
 E       AssertionError: assert 'test2' == 'test'
-E         ⏎
+E         \n\
 E         - test
 E         + test2
 E         ?     +
@@ -157,7 +157,7 @@ def test_a():
         """\
 >       assert outsource(b"test2") == snapshot(
 E       AssertionError: assert b'test2' == b'test'
-E         ⏎
+E         \n\
 E         Use -v to get more diff
 """
     )
